# This file was created automatically by SWIG.
import controlsc

from misc import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *
import wx
class wxControlPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxControl_Create,(self,) + _args, _kwargs)
        return val
    def Command(self, *_args, **_kwargs):
        val = apply(controlsc.wxControl_Command,(self,) + _args, _kwargs)
        return val
    def GetLabel(self, *_args, **_kwargs):
        val = apply(controlsc.wxControl_GetLabel,(self,) + _args, _kwargs)
        return val
    def SetLabel(self, *_args, **_kwargs):
        val = apply(controlsc.wxControl_SetLabel,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxControl instance at %s>" % (self.this,)
class wxControl(wxControlPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxControl,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreControl(*_args,**_kwargs):
    val = wxControlPtr(apply(controlsc.new_wxPreControl,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxControlWithItemsPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Delete(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_Delete,(self,) + _args, _kwargs)
        return val
    def GetCount(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_GetCount,(self,) + _args, _kwargs)
        return val
    def GetString(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_GetString,(self,) + _args, _kwargs)
        return val
    def SetString(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_SetString,(self,) + _args, _kwargs)
        return val
    def FindString(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_FindString,(self,) + _args, _kwargs)
        return val
    def Select(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_Select,(self,) + _args, _kwargs)
        return val
    def GetSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_GetSelection,(self,) + _args, _kwargs)
        return val
    def GetStringSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_GetStringSelection,(self,) + _args, _kwargs)
        return val
    def Append(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_Append,(self,) + _args, _kwargs)
        return val
    def GetClientData(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_GetClientData,(self,) + _args, _kwargs)
        return val
    def SetClientData(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_SetClientData,(self,) + _args, _kwargs)
        return val
    def AppendItems(self, *_args, **_kwargs):
        val = apply(controlsc.wxControlWithItems_AppendItems,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxControlWithItems instance at %s>" % (self.this,)
    Number = GetCount
class wxControlWithItems(wxControlWithItemsPtr):
    def __init__(self,this):
        self.this = this




class wxButtonPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxButton_Create,(self,) + _args, _kwargs)
        return val
    def SetDefault(self, *_args, **_kwargs):
        val = apply(controlsc.wxButton_SetDefault,(self,) + _args, _kwargs)
        return val
    def SetBackgroundColour(self, *_args, **_kwargs):
        val = apply(controlsc.wxButton_SetBackgroundColour,(self,) + _args, _kwargs)
        return val
    def SetForegroundColour(self, *_args, **_kwargs):
        val = apply(controlsc.wxButton_SetForegroundColour,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxButton instance at %s>" % (self.this,)
class wxButton(wxButtonPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxButton,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreButton(*_args,**_kwargs):
    val = wxButtonPtr(apply(controlsc.new_wxPreButton,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxBitmapButtonPtr(wxButtonPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_Create,(self,) + _args, _kwargs)
        return val
    def GetBitmapLabel(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_GetBitmapLabel,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def GetBitmapDisabled(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_GetBitmapDisabled,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def GetBitmapFocus(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_GetBitmapFocus,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def GetBitmapSelected(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_GetBitmapSelected,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def SetBitmapDisabled(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_SetBitmapDisabled,(self,) + _args, _kwargs)
        return val
    def SetBitmapFocus(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_SetBitmapFocus,(self,) + _args, _kwargs)
        return val
    def SetBitmapSelected(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_SetBitmapSelected,(self,) + _args, _kwargs)
        return val
    def SetBitmapLabel(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_SetBitmapLabel,(self,) + _args, _kwargs)
        return val
    def SetMargins(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_SetMargins,(self,) + _args, _kwargs)
        return val
    def GetMarginX(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_GetMarginX,(self,) + _args, _kwargs)
        return val
    def GetMarginY(self, *_args, **_kwargs):
        val = apply(controlsc.wxBitmapButton_GetMarginY,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxBitmapButton instance at %s>" % (self.this,)
class wxBitmapButton(wxBitmapButtonPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxBitmapButton,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreBitmapButton(*_args,**_kwargs):
    val = wxBitmapButtonPtr(apply(controlsc.new_wxPreBitmapButton,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxCheckBoxPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckBox_Create,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckBox_GetValue,(self,) + _args, _kwargs)
        return val
    def IsChecked(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckBox_IsChecked,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckBox_SetValue,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxCheckBox instance at %s>" % (self.this,)
class wxCheckBox(wxCheckBoxPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxCheckBox,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreCheckBox(*_args,**_kwargs):
    val = wxCheckBoxPtr(apply(controlsc.new_wxPreCheckBox,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxChoicePtr(wxControlWithItemsPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxChoice_Create,(self,) + _args, _kwargs)
        return val
    def Clear(self, *_args, **_kwargs):
        val = apply(controlsc.wxChoice_Clear,(self,) + _args, _kwargs)
        return val
    def GetColumns(self, *_args, **_kwargs):
        val = apply(controlsc.wxChoice_GetColumns,(self,) + _args, _kwargs)
        return val
    def SetColumns(self, *_args, **_kwargs):
        val = apply(controlsc.wxChoice_SetColumns,(self,) + _args, _kwargs)
        return val
    def SetSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxChoice_SetSelection,(self,) + _args, _kwargs)
        return val
    def SetStringSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxChoice_SetStringSelection,(self,) + _args, _kwargs)
        return val
    def SetString(self, *_args, **_kwargs):
        val = apply(controlsc.wxChoice_SetString,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxChoice instance at %s>" % (self.this,)
    
    Select = SetSelection
    
class wxChoice(wxChoicePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxChoice,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreChoice(*_args,**_kwargs):
    val = wxChoicePtr(apply(controlsc.new_wxPreChoice,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxComboBoxPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_Create,(self,) + _args, _kwargs)
        return val
    def Copy(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_Copy,(self,) + _args, _kwargs)
        return val
    def Cut(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_Cut,(self,) + _args, _kwargs)
        return val
    def GetInsertionPoint(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_GetInsertionPoint,(self,) + _args, _kwargs)
        return val
    def GetLastPosition(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_GetLastPosition,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_GetValue,(self,) + _args, _kwargs)
        return val
    def Paste(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_Paste,(self,) + _args, _kwargs)
        return val
    def Replace(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_Replace,(self,) + _args, _kwargs)
        return val
    def Remove(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_Remove,(self,) + _args, _kwargs)
        return val
    def SetInsertionPoint(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_SetInsertionPoint,(self,) + _args, _kwargs)
        return val
    def SetInsertionPointEnd(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_SetInsertionPointEnd,(self,) + _args, _kwargs)
        return val
    def SetSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_SetSelection,(self,) + _args, _kwargs)
        return val
    def SetMark(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_SetMark,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_SetValue,(self,) + _args, _kwargs)
        return val
    def SetEditable(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_SetEditable,(self,) + _args, _kwargs)
        return val
    def Clear(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_Clear,(self,) + _args, _kwargs)
        return val
    def Delete(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_Delete,(self,) + _args, _kwargs)
        return val
    def GetCount(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_GetCount,(self,) + _args, _kwargs)
        return val
    def GetString(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_GetString,(self,) + _args, _kwargs)
        return val
    def FindString(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_FindString,(self,) + _args, _kwargs)
        return val
    def GetSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_GetSelection,(self,) + _args, _kwargs)
        return val
    def GetStringSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_GetStringSelection,(self,) + _args, _kwargs)
        return val
    def Append(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_Append,(self,) + _args, _kwargs)
        return val
    def GetClientData(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_GetClientData,(self,) + _args, _kwargs)
        return val
    def SetClientData(self, *_args, **_kwargs):
        val = apply(controlsc.wxComboBox_SetClientData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxComboBox instance at %s>" % (self.this,)
    Number = GetCount
    Select = SetSelection
class wxComboBox(wxComboBoxPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxComboBox,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreComboBox(*_args,**_kwargs):
    val = wxComboBoxPtr(apply(controlsc.new_wxPreComboBox,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxGaugePtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxGauge_Create,(self,) + _args, _kwargs)
        return val
    def GetBezelFace(self, *_args, **_kwargs):
        val = apply(controlsc.wxGauge_GetBezelFace,(self,) + _args, _kwargs)
        return val
    def GetRange(self, *_args, **_kwargs):
        val = apply(controlsc.wxGauge_GetRange,(self,) + _args, _kwargs)
        return val
    def GetShadowWidth(self, *_args, **_kwargs):
        val = apply(controlsc.wxGauge_GetShadowWidth,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxGauge_GetValue,(self,) + _args, _kwargs)
        return val
    def SetBezelFace(self, *_args, **_kwargs):
        val = apply(controlsc.wxGauge_SetBezelFace,(self,) + _args, _kwargs)
        return val
    def SetRange(self, *_args, **_kwargs):
        val = apply(controlsc.wxGauge_SetRange,(self,) + _args, _kwargs)
        return val
    def SetShadowWidth(self, *_args, **_kwargs):
        val = apply(controlsc.wxGauge_SetShadowWidth,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxGauge_SetValue,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGauge instance at %s>" % (self.this,)
class wxGauge(wxGaugePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxGauge,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreGauge(*_args,**_kwargs):
    val = wxGaugePtr(apply(controlsc.new_wxPreGauge,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxStaticBoxPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxStaticBox_Create,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxStaticBox instance at %s>" % (self.this,)
class wxStaticBox(wxStaticBoxPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxStaticBox,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreStaticBox(*_args,**_kwargs):
    val = wxStaticBoxPtr(apply(controlsc.new_wxPreStaticBox,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxStaticLinePtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxStaticLine_Create,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxStaticLine instance at %s>" % (self.this,)
class wxStaticLine(wxStaticLinePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxStaticLine,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreStaticLine(*_args,**_kwargs):
    val = wxStaticLinePtr(apply(controlsc.new_wxPreStaticLine,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxStaticTextPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxStaticText_Create,(self,) + _args, _kwargs)
        return val
    def GetLabel(self, *_args, **_kwargs):
        val = apply(controlsc.wxStaticText_GetLabel,(self,) + _args, _kwargs)
        return val
    def SetLabel(self, *_args, **_kwargs):
        val = apply(controlsc.wxStaticText_SetLabel,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxStaticText instance at %s>" % (self.this,)
class wxStaticText(wxStaticTextPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxStaticText,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreStaticText(*_args,**_kwargs):
    val = wxStaticTextPtr(apply(controlsc.new_wxPreStaticText,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxListBoxPtr(wxControlWithItemsPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_Create,(self,) + _args, _kwargs)
        return val
    def Clear(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_Clear,(self,) + _args, _kwargs)
        return val
    def Deselect(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_Deselect,(self,) + _args, _kwargs)
        return val
    def GetSelections(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_GetSelections,(self,) + _args, _kwargs)
        return val
    def InsertItems(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_InsertItems,(self,) + _args, _kwargs)
        return val
    def IsSelected(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_IsSelected,(self,) + _args, _kwargs)
        return val
    def Selected(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_Selected,(self,) + _args, _kwargs)
        return val
    def Set(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_Set,(self,) + _args, _kwargs)
        return val
    def SetFirstItem(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_SetFirstItem,(self,) + _args, _kwargs)
        return val
    def SetFirstItemStr(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_SetFirstItemStr,(self,) + _args, _kwargs)
        return val
    def SetSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_SetSelection,(self,) + _args, _kwargs)
        return val
    def SetString(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_SetString,(self,) + _args, _kwargs)
        return val
    def SetStringSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxListBox_SetStringSelection,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxListBox instance at %s>" % (self.this,)
class wxListBox(wxListBoxPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxListBox,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreListBox(*_args,**_kwargs):
    val = wxListBoxPtr(apply(controlsc.new_wxPreListBox,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxCheckListBoxPtr(wxListBoxPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckListBox_Create,(self,) + _args, _kwargs)
        return val
    def IsChecked(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckListBox_IsChecked,(self,) + _args, _kwargs)
        return val
    def Check(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckListBox_Check,(self,) + _args, _kwargs)
        return val
    def InsertItems(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckListBox_InsertItems,(self,) + _args, _kwargs)
        return val
    def GetItemHeight(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckListBox_GetItemHeight,(self,) + _args, _kwargs)
        return val
    def HitTest(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckListBox_HitTest,(self,) + _args, _kwargs)
        return val
    def HitTestXY(self, *_args, **_kwargs):
        val = apply(controlsc.wxCheckListBox_HitTestXY,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxCheckListBox instance at %s>" % (self.this,)
class wxCheckListBox(wxCheckListBoxPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxCheckListBox,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreCheckListBox(*_args,**_kwargs):
    val = wxCheckListBoxPtr(apply(controlsc.new_wxPreCheckListBox,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxTextAttrPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=controlsc.delete_wxTextAttr):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetTextColour(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextAttr_SetTextColour,(self,) + _args, _kwargs)
        return val
    def SetBackgroundColour(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextAttr_SetBackgroundColour,(self,) + _args, _kwargs)
        return val
    def SetFont(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextAttr_SetFont,(self,) + _args, _kwargs)
        return val
    def HasTextColour(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextAttr_HasTextColour,(self,) + _args, _kwargs)
        return val
    def HasBackgroundColour(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextAttr_HasBackgroundColour,(self,) + _args, _kwargs)
        return val
    def HasFont(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextAttr_HasFont,(self,) + _args, _kwargs)
        return val
    def GetTextColour(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextAttr_GetTextColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetBackgroundColour(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextAttr_GetBackgroundColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetFont(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextAttr_GetFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def IsDefault(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextAttr_IsDefault,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTextAttr instance at %s>" % (self.this,)
class wxTextAttr(wxTextAttrPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxTextAttr,_args,_kwargs)
        self.thisown = 1




class wxTextCtrlPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_Create,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetValue,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_SetValue,(self,) + _args, _kwargs)
        return val
    def GetRange(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetRange,(self,) + _args, _kwargs)
        return val
    def GetLineLength(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetLineLength,(self,) + _args, _kwargs)
        return val
    def GetLineText(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetLineText,(self,) + _args, _kwargs)
        return val
    def GetNumberOfLines(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetNumberOfLines,(self,) + _args, _kwargs)
        return val
    def IsModified(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_IsModified,(self,) + _args, _kwargs)
        return val
    def IsEditable(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_IsEditable,(self,) + _args, _kwargs)
        return val
    def GetSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetSelection,(self,) + _args, _kwargs)
        return val
    def GetStringSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetStringSelection,(self,) + _args, _kwargs)
        return val
    def Clear(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_Clear,(self,) + _args, _kwargs)
        return val
    def Replace(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_Replace,(self,) + _args, _kwargs)
        return val
    def Remove(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_Remove,(self,) + _args, _kwargs)
        return val
    def LoadFile(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_LoadFile,(self,) + _args, _kwargs)
        return val
    def SaveFile(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_SaveFile,(self,) + _args, _kwargs)
        return val
    def DiscardEdits(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_DiscardEdits,(self,) + _args, _kwargs)
        return val
    def SetMaxLength(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_SetMaxLength,(self,) + _args, _kwargs)
        return val
    def WriteText(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_WriteText,(self,) + _args, _kwargs)
        return val
    def AppendText(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_AppendText,(self,) + _args, _kwargs)
        return val
    def EmulateKeyPress(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_EmulateKeyPress,(self,) + _args, _kwargs)
        return val
    def SetStyle(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_SetStyle,(self,) + _args, _kwargs)
        return val
    def SetDefaultStyle(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_SetDefaultStyle,(self,) + _args, _kwargs)
        return val
    def GetDefaultStyle(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetDefaultStyle,(self,) + _args, _kwargs)
        if val: val = wxTextAttrPtr(val) 
        return val
    def XYToPosition(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_XYToPosition,(self,) + _args, _kwargs)
        return val
    def PositionToXY(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_PositionToXY,(self,) + _args, _kwargs)
        return val
    def ShowPosition(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_ShowPosition,(self,) + _args, _kwargs)
        return val
    def Copy(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_Copy,(self,) + _args, _kwargs)
        return val
    def Cut(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_Cut,(self,) + _args, _kwargs)
        return val
    def Paste(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_Paste,(self,) + _args, _kwargs)
        return val
    def CanCopy(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_CanCopy,(self,) + _args, _kwargs)
        return val
    def CanCut(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_CanCut,(self,) + _args, _kwargs)
        return val
    def CanPaste(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_CanPaste,(self,) + _args, _kwargs)
        return val
    def Undo(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_Undo,(self,) + _args, _kwargs)
        return val
    def Redo(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_Redo,(self,) + _args, _kwargs)
        return val
    def CanUndo(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_CanUndo,(self,) + _args, _kwargs)
        return val
    def CanRedo(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_CanRedo,(self,) + _args, _kwargs)
        return val
    def SetInsertionPoint(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_SetInsertionPoint,(self,) + _args, _kwargs)
        return val
    def SetInsertionPointEnd(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_SetInsertionPointEnd,(self,) + _args, _kwargs)
        return val
    def GetInsertionPoint(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetInsertionPoint,(self,) + _args, _kwargs)
        return val
    def GetLastPosition(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetLastPosition,(self,) + _args, _kwargs)
        return val
    def SetSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_SetSelection,(self,) + _args, _kwargs)
        return val
    def SelectAll(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_SelectAll,(self,) + _args, _kwargs)
        return val
    def SetEditable(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_SetEditable,(self,) + _args, _kwargs)
        return val
    def IsSingleLine(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_IsSingleLine,(self,) + _args, _kwargs)
        return val
    def IsMultiLine(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_IsMultiLine,(self,) + _args, _kwargs)
        return val
    def write(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_write,(self,) + _args, _kwargs)
        return val
    def GetString(self, *_args, **_kwargs):
        val = apply(controlsc.wxTextCtrl_GetString,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTextCtrl instance at %s>" % (self.this,)
class wxTextCtrl(wxTextCtrlPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxTextCtrl,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreTextCtrl(*_args,**_kwargs):
    val = wxTextCtrlPtr(apply(controlsc.new_wxPreTextCtrl,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxScrollBarPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxScrollBar_Create,(self,) + _args, _kwargs)
        return val
    def GetRange(self, *_args, **_kwargs):
        val = apply(controlsc.wxScrollBar_GetRange,(self,) + _args, _kwargs)
        return val
    def GetPageSize(self, *_args, **_kwargs):
        val = apply(controlsc.wxScrollBar_GetPageSize,(self,) + _args, _kwargs)
        return val
    def GetThumbPosition(self, *_args, **_kwargs):
        val = apply(controlsc.wxScrollBar_GetThumbPosition,(self,) + _args, _kwargs)
        return val
    def GetThumbSize(self, *_args, **_kwargs):
        val = apply(controlsc.wxScrollBar_GetThumbSize,(self,) + _args, _kwargs)
        return val
    def GetThumbLength(self, *_args, **_kwargs):
        val = apply(controlsc.wxScrollBar_GetThumbLength,(self,) + _args, _kwargs)
        return val
    def IsVertical(self, *_args, **_kwargs):
        val = apply(controlsc.wxScrollBar_IsVertical,(self,) + _args, _kwargs)
        return val
    def SetThumbPosition(self, *_args, **_kwargs):
        val = apply(controlsc.wxScrollBar_SetThumbPosition,(self,) + _args, _kwargs)
        return val
    def SetScrollbar(self, *_args, **_kwargs):
        val = apply(controlsc.wxScrollBar_SetScrollbar,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxScrollBar instance at %s>" % (self.this,)
class wxScrollBar(wxScrollBarPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxScrollBar,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreScrollBar(*_args,**_kwargs):
    val = wxScrollBarPtr(apply(controlsc.new_wxPreScrollBar,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxSpinButtonPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinButton_Create,(self,) + _args, _kwargs)
        return val
    def GetMax(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinButton_GetMax,(self,) + _args, _kwargs)
        return val
    def GetMin(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinButton_GetMin,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinButton_GetValue,(self,) + _args, _kwargs)
        return val
    def SetRange(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinButton_SetRange,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinButton_SetValue,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSpinButton instance at %s>" % (self.this,)
class wxSpinButton(wxSpinButtonPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxSpinButton,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreSpinButton(*_args,**_kwargs):
    val = wxSpinButtonPtr(apply(controlsc.new_wxPreSpinButton,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxStaticBitmapPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxStaticBitmap_Create,(self,) + _args, _kwargs)
        return val
    def GetBitmap(self, *_args, **_kwargs):
        val = apply(controlsc.wxStaticBitmap_GetBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def SetBitmap(self, *_args, **_kwargs):
        val = apply(controlsc.wxStaticBitmap_SetBitmap,(self,) + _args, _kwargs)
        return val
    def SetIcon(self, *_args, **_kwargs):
        val = apply(controlsc.wxStaticBitmap_SetIcon,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxStaticBitmap instance at %s>" % (self.this,)
class wxStaticBitmap(wxStaticBitmapPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxStaticBitmap,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreStaticBitmap(*_args,**_kwargs):
    val = wxStaticBitmapPtr(apply(controlsc.new_wxPreStaticBitmap,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxRadioBoxPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_Create,(self,) + _args, _kwargs)
        return val
    def Enable(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_Enable,(self,) + _args, _kwargs)
        return val
    def EnableItem(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_EnableItem,(self,) + _args, _kwargs)
        return val
    def FindString(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_FindString,(self,) + _args, _kwargs)
        return val
    def GetString(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_GetString,(self,) + _args, _kwargs)
        return val
    def GetItemLabel(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_GetItemLabel,(self,) + _args, _kwargs)
        return val
    def SetItemLabel(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_SetItemLabel,(self,) + _args, _kwargs)
        return val
    def GetSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_GetSelection,(self,) + _args, _kwargs)
        return val
    def GetStringSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_GetStringSelection,(self,) + _args, _kwargs)
        return val
    def GetCount(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_GetCount,(self,) + _args, _kwargs)
        return val
    def SetSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_SetSelection,(self,) + _args, _kwargs)
        return val
    def SetStringSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_SetStringSelection,(self,) + _args, _kwargs)
        return val
    def Show(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_Show,(self,) + _args, _kwargs)
        return val
    def ShowItem(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioBox_ShowItem,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxRadioBox instance at %s>" % (self.this,)
    Number = GetCount
class wxRadioBox(wxRadioBoxPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxRadioBox,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreRadioBox(*_args,**_kwargs):
    val = wxRadioBoxPtr(apply(controlsc.new_wxPreRadioBox,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxRadioButtonPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioButton_Create,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioButton_GetValue,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxRadioButton_SetValue,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxRadioButton instance at %s>" % (self.this,)
class wxRadioButton(wxRadioButtonPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxRadioButton,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreRadioButton(*_args,**_kwargs):
    val = wxRadioButtonPtr(apply(controlsc.new_wxPreRadioButton,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxSliderPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_Create,(self,) + _args, _kwargs)
        return val
    def ClearSel(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_ClearSel,(self,) + _args, _kwargs)
        return val
    def ClearTicks(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_ClearTicks,(self,) + _args, _kwargs)
        return val
    def GetLineSize(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_GetLineSize,(self,) + _args, _kwargs)
        return val
    def GetMax(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_GetMax,(self,) + _args, _kwargs)
        return val
    def GetMin(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_GetMin,(self,) + _args, _kwargs)
        return val
    def GetPageSize(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_GetPageSize,(self,) + _args, _kwargs)
        return val
    def GetSelEnd(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_GetSelEnd,(self,) + _args, _kwargs)
        return val
    def GetSelStart(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_GetSelStart,(self,) + _args, _kwargs)
        return val
    def GetThumbLength(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_GetThumbLength,(self,) + _args, _kwargs)
        return val
    def GetTickFreq(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_GetTickFreq,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_GetValue,(self,) + _args, _kwargs)
        return val
    def SetRange(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_SetRange,(self,) + _args, _kwargs)
        return val
    def SetTickFreq(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_SetTickFreq,(self,) + _args, _kwargs)
        return val
    def SetLineSize(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_SetLineSize,(self,) + _args, _kwargs)
        return val
    def SetPageSize(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_SetPageSize,(self,) + _args, _kwargs)
        return val
    def SetSelection(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_SetSelection,(self,) + _args, _kwargs)
        return val
    def SetThumbLength(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_SetThumbLength,(self,) + _args, _kwargs)
        return val
    def SetTick(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_SetTick,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxSlider_SetValue,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSlider instance at %s>" % (self.this,)
class wxSlider(wxSliderPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxSlider,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreSlider(*_args,**_kwargs):
    val = wxSliderPtr(apply(controlsc.new_wxPreSlider,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxSpinCtrlPtr(wxSpinButtonPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinCtrl_Create,(self,) + _args, _kwargs)
        return val
    def GetMax(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinCtrl_GetMax,(self,) + _args, _kwargs)
        return val
    def GetMin(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinCtrl_GetMin,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinCtrl_GetValue,(self,) + _args, _kwargs)
        return val
    def SetRange(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinCtrl_SetRange,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxSpinCtrl_SetValue,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSpinCtrl instance at %s>" % (self.this,)
class wxSpinCtrl(wxSpinCtrlPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxSpinCtrl,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreSpinCtrl(*_args,**_kwargs):
    val = wxSpinCtrlPtr(apply(controlsc.new_wxPreSpinCtrl,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxToggleButtonPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(controlsc.wxToggleButton_Create,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxToggleButton_SetValue,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(controlsc.wxToggleButton_GetValue,(self,) + _args, _kwargs)
        return val
    def SetLabel(self, *_args, **_kwargs):
        val = apply(controlsc.wxToggleButton_SetLabel,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxToggleButton instance at %s>" % (self.this,)
class wxToggleButton(wxToggleButtonPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(controlsc.new_wxToggleButton,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreToggleButton(*_args,**_kwargs):
    val = wxToggleButtonPtr(apply(controlsc.new_wxPreToggleButton,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val




#-------------- FUNCTION WRAPPERS ------------------

def wxButton_GetDefaultSize(*_args, **_kwargs):
    val = apply(controlsc.wxButton_GetDefaultSize,_args,_kwargs)
    if val: val = wxSizePtr(val); val.thisown = 1
    return val

def wxTextAttr_Combine(*_args, **_kwargs):
    val = apply(controlsc.wxTextAttr_Combine,_args,_kwargs)
    if val: val = wxTextAttrPtr(val); val.thisown = 1
    return val



#-------------- VARIABLE WRAPPERS ------------------

cvar = controlsc.cvar
wxDefaultValidator = wxValidatorPtr(controlsc.cvar.wxDefaultValidator)
wxEVT_COMMAND_TOGGLEBUTTON_CLICKED = controlsc.wxEVT_COMMAND_TOGGLEBUTTON_CLICKED



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: FileSystem.py,v 1.1.2.1 2003/03/11 19:37:12 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import Object
import Parameters as wx


class FSFile(Object):
    """"""

    def GetAnchor(self):
        """"""
        pass

    def GetLocation(self):
        """"""
        pass

    def GetMimeType(self):
        """"""
        pass

    def GetModificationTime(self):
        """"""
        pass

    def GetStream(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FileSystem(Object):
    """"""

    def ChangePathTo(self):
        """"""
        pass

    def FindFirst(self):
        """"""
        pass

    def FindNext(self):
        """"""
        pass

    def GetPath(self):
        """"""
        pass

    def OpenFile(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class CPPFileSystemHandler(Object):
    """"""

    def __init__(self):
        """"""
        pass


class FileSystemHandler(CPPFileSystemHandler):
    """"""

    def CanOpen(self):
        """"""
        pass

    def FindFirst(self):
        """"""
        pass

    def FindNext(self):
        """"""
        pass

    def GetAnchor(self):
        """"""
        pass

    def GetLeftLocation(self):
        """"""
        pass

    def GetMimeTypeFromExt(self):
        """"""
        pass

    def GetProtocol(self):
        """"""
        pass

    def GetRightLocation(self):
        """"""
        pass

    def OpenFile(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass


class InternetFSHandler(CPPFileSystemHandler):
    """"""

    def CanOpen(self):
        """"""
        pass

    def OpenFile(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class MemoryFSHandler(CPPFileSystemHandler):
    """"""

    def CanOpen(self):
        """"""
        pass

    def FindFirst(self):
        """"""
        pass

    def FindNext(self):
        """"""
        pass

    def OpenFile(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ZipFSHandler(CPPFileSystemHandler):
    """"""

    def CanOpen(self):
        """"""
        pass

    def FindFirst(self):
        """"""
        pass

    def FindNext(self):
        """"""
        pass

    def OpenFile(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass




# This file was created automatically by SWIG.
import streamsc
import wx
class wxInputStreamPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def close(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_close,(self,) + _args, _kwargs)
        return val
    def flush(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_flush,(self,) + _args, _kwargs)
        return val
    def eof(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_eof,(self,) + _args, _kwargs)
        return val
    def read(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_read,(self,) + _args, _kwargs)
        return val
    def readline(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_readline,(self,) + _args, _kwargs)
        return val
    def readlines(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_readlines,(self,) + _args, _kwargs)
        return val
    def seek(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_seek,(self,) + _args, _kwargs)
        return val
    def tell(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_tell,(self,) + _args, _kwargs)
        return val
    def Peek(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_Peek,(self,) + _args, _kwargs)
        return val
    def GetC(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_GetC,(self,) + _args, _kwargs)
        return val
    def LastRead(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_LastRead,(self,) + _args, _kwargs)
        return val
    def CanRead(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_CanRead,(self,) + _args, _kwargs)
        return val
    def Eof(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_Eof,(self,) + _args, _kwargs)
        return val
    def Ungetch(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_Ungetch,(self,) + _args, _kwargs)
        return val
    def SeekI(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_SeekI,(self,) + _args, _kwargs)
        return val
    def TellI(self, *_args, **_kwargs):
        val = apply(streamsc.wxInputStream_TellI,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxInputStream instance at %s>" % (self.this,)
class wxInputStream(wxInputStreamPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(streamsc.new_wxInputStream,_args,_kwargs)
        self.thisown = 1




class wxOutputStreamPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def write(self, *_args, **_kwargs):
        val = apply(streamsc.wxOutputStream_write,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxOutputStream instance at %s>" % (self.this,)
class wxOutputStream(wxOutputStreamPtr):
    def __init__(self,this):
        self.this = this






#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------

wxFromStart = streamsc.wxFromStart
wxFromCurrent = streamsc.wxFromCurrent
wxFromEnd = streamsc.wxFromEnd



__cvsid__ = "$Id: DateTime.py,v 1.1.2.1 2003/03/11 19:37:13 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx


class DateSpan:
    """"""

    def Add(self):
        """"""
        pass

    def GetDays(self):
        """"""
        pass

    def GetMonths(self):
        """"""
        pass

    def GetTotalDays(self):
        """"""
        pass

    def GetWeeks(self):
        """"""
        pass

    def GetYears(self):
        """"""
        pass

    def Multiply(self):
        """"""
        pass

    def Neg(self):
        """"""
        pass

    def SetDays(self):
        """"""
        pass

    def SetMonths(self):
        """"""
        pass

    def SetWeeks(self):
        """"""
        pass

    def SetYears(self):
        """"""
        pass

    def Subtract(self):
        """"""
        pass

    def __add__(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __mul__(self):
        """"""
        pass

    def __neg__(self):
        """"""
        pass

    def __rmul__(self):
        """"""
        pass

    def __sub__(self):
        """"""
        pass


class DateTime:
    """"""

    def AddDS(self):
        """"""
        pass

    def AddTS(self):
        """"""
        pass

    def Format(self):
        """"""
        pass

    def FormatDate(self):
        """"""
        pass

    def FormatISODate(self):
        """"""
        pass

    def FormatISOTime(self):
        """"""
        pass

    def FormatTime(self):
        """"""
        pass

    def GetDay(self):
        """"""
        pass

    def GetDayOfYear(self):
        """"""
        pass

    def GetHour(self):
        """"""
        pass

    def GetJDN(self):
        """"""
        pass

    def GetJulianDayNumber(self):
        """"""
        pass

    def GetLastMonthDay(self):
        """"""
        pass

    def GetLastWeekDay(self):
        """"""
        pass

    def GetMJD(self):
        """"""
        pass

    def GetMillisecond(self):
        """"""
        pass

    def GetMinute(self):
        """"""
        pass

    def GetModifiedJulianDayNumber(self):
        """"""
        pass

    def GetMonth(self):
        """"""
        pass

    def GetNextWeekDay(self):
        """"""
        pass

    def GetPrevWeekDay(self):
        """"""
        pass

    def GetRataDie(self):
        """"""
        pass

    def GetSecond(self):
        """"""
        pass

    def GetTicks(self):
        """"""
        pass

    def GetWeek(self):
        """"""
        pass

    def GetWeekDay(self):
        """"""
        pass

    def GetWeekDayInSameWeek(self):
        """"""
        pass

    def GetWeekOfMonth(self):
        """"""
        pass

    def GetWeekOfYear(self):
        """"""
        pass

    def GetYear(self):
        """"""
        pass

    def GetYearDay(self):
        """"""
        pass

    def IsBetween(self):
        """"""
        pass

    def IsDST(self):
        """"""
        pass

    def IsEarlierThan(self):
        """"""
        pass

    def IsEqualTo(self):
        """"""
        pass

    def IsEqualUpTo(self):
        """"""
        pass

    def IsLaterThan(self):
        """"""
        pass

    def IsSameDate(self):
        """"""
        pass

    def IsSameTime(self):
        """"""
        pass

    def IsStrictlyBetween(self):
        """"""
        pass

    def IsValid(self):
        """"""
        pass

    def IsWorkDay(self):
        """"""
        pass

    def MakeGMT(self):
        """"""
        pass

    def MakeTimezone(self):
        """"""
        pass

    def ParseDate(self):
        """"""
        pass

    def ParseDateTime(self):
        """"""
        pass

    def ParseFormat(self):
        """"""
        pass

    def ParseRfc822Date(self):
        """"""
        pass

    def ParseTime(self):
        """"""
        pass

    def ResetTime(self):
        """"""
        pass

    def Set(self):
        """"""
        pass

    def SetDay(self):
        """"""
        pass

    def SetHMS(self):
        """"""
        pass

    def SetHour(self):
        """"""
        pass

    def SetJDN(self):
        """"""
        pass

    def SetMillisecond(self):
        """"""
        pass

    def SetMinute(self):
        """"""
        pass

    def SetMonth(self):
        """"""
        pass

    def SetSecond(self):
        """"""
        pass

    def SetTimeT(self):
        """"""
        pass

    def SetToCurrent(self):
        """"""
        pass

    def SetToLastMonthDay(self):
        """"""
        pass

    def SetToLastWeekDay(self):
        """"""
        pass

    def SetToNextWeekDay(self):
        """"""
        pass

    def SetToPrevWeekDay(self):
        """"""
        pass

    def SetToTheWeek(self):
        """"""
        pass

    def SetToWeekDay(self):
        """"""
        pass

    def SetToWeekDayInSameWeek(self):
        """"""
        pass

    def SetToYearDay(self):
        """"""
        pass

    def SetYear(self):
        """"""
        pass

    def Subtract(self):
        """"""
        pass

    def SubtractDS(self):
        """"""
        pass

    def SubtractTS(self):
        """"""
        pass

    def ToGMT(self):
        """"""
        pass

    def ToTimezone(self):
        """"""
        pass

    def __add__(self):
        """"""
        pass

    def __cmp__(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __str__(self):
        """"""
        pass

    def __sub__(self):
        """"""
        pass

    def _wxDateTimePtr__add__DS(self):
        """"""
        pass

    def _wxDateTimePtr__add__TS(self):
        """"""
        pass

    def _wxDateTimePtr__sub__DS(self):
        """"""
        pass

    def _wxDateTimePtr__sub__DT(self):
        """"""
        pass

    def _wxDateTimePtr__sub__TS(self):
        """"""
        pass


class TimeSpan:
    """"""

    def Abs(self):
        """"""
        pass

    def Add(self):
        """"""
        pass

    def Format(self):
        """"""
        pass

    def GetDays(self):
        """"""
        pass

    def GetHours(self):
        """"""
        pass

    def GetMilliseconds(self):
        """"""
        pass

    def GetMinutes(self):
        """"""
        pass

    def GetSeconds(self):
        """"""
        pass

    def GetWeeks(self):
        """"""
        pass

    def IsEqualTo(self):
        """"""
        pass

    def IsLongerThan(self):
        """"""
        pass

    def IsNegative(self):
        """"""
        pass

    def IsNull(self):
        """"""
        pass

    def IsPositive(self):
        """"""
        pass

    def IsShorterThan(self):
        """"""
        pass

    def Multiply(self):
        """"""
        pass

    def Neg(self):
        """"""
        pass

    def Subtract(self):
        """"""
        pass

    def __add__(self):
        """"""
        pass

    def __cmp__(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __mul__(self):
        """"""
        pass

    def __neg__(self):
        """"""
        pass

    def __rmul__(self):
        """"""
        pass

    def __sub__(self):
        """"""
        pass





# This file was created automatically by SWIG.
import windows3c

from misc import *

from gdi import *

from fonts import *

from windows import *

from clip_dnd import *

from windows2 import *

from controls import *

from events import *

from mdi import *

from frames import *

from stattool import *
import wx
class wxSashEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetEdge(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashEvent_SetEdge,(self,) + _args, _kwargs)
        return val
    def GetEdge(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashEvent_GetEdge,(self,) + _args, _kwargs)
        return val
    def SetDragRect(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashEvent_SetDragRect,(self,) + _args, _kwargs)
        return val
    def GetDragRect(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashEvent_GetDragRect,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def SetDragStatus(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashEvent_SetDragStatus,(self,) + _args, _kwargs)
        return val
    def GetDragStatus(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashEvent_GetDragStatus,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSashEvent instance at %s>" % (self.this,)
class wxSashEvent(wxSashEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows3c.new_wxSashEvent,_args,_kwargs)
        self.thisown = 1




class wxSashWindowPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_Create,(self,) + _args, _kwargs)
        return val
    def GetSashVisible(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_GetSashVisible,(self,) + _args, _kwargs)
        return val
    def GetDefaultBorderSize(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_GetDefaultBorderSize,(self,) + _args, _kwargs)
        return val
    def GetEdgeMargin(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_GetEdgeMargin,(self,) + _args, _kwargs)
        return val
    def GetExtraBorderSize(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_GetExtraBorderSize,(self,) + _args, _kwargs)
        return val
    def GetMaximumSizeX(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_GetMaximumSizeX,(self,) + _args, _kwargs)
        return val
    def GetMaximumSizeY(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_GetMaximumSizeY,(self,) + _args, _kwargs)
        return val
    def GetMinimumSizeX(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_GetMinimumSizeX,(self,) + _args, _kwargs)
        return val
    def GetMinimumSizeY(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_GetMinimumSizeY,(self,) + _args, _kwargs)
        return val
    def HasBorder(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_HasBorder,(self,) + _args, _kwargs)
        return val
    def SetDefaultBorderSize(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_SetDefaultBorderSize,(self,) + _args, _kwargs)
        return val
    def SetExtraBorderSize(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_SetExtraBorderSize,(self,) + _args, _kwargs)
        return val
    def SetMaximumSizeX(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_SetMaximumSizeX,(self,) + _args, _kwargs)
        return val
    def SetMaximumSizeY(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_SetMaximumSizeY,(self,) + _args, _kwargs)
        return val
    def SetMinimumSizeX(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_SetMinimumSizeX,(self,) + _args, _kwargs)
        return val
    def SetMinimumSizeY(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_SetMinimumSizeY,(self,) + _args, _kwargs)
        return val
    def SetSashVisible(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_SetSashVisible,(self,) + _args, _kwargs)
        return val
    def SetSashBorder(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashWindow_SetSashBorder,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSashWindow instance at %s>" % (self.this,)
class wxSashWindow(wxSashWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows3c.new_wxSashWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreSashWindow(*_args,**_kwargs):
    val = wxSashWindowPtr(apply(windows3c.new_wxPreSashWindow,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxQueryLayoutInfoEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetRequestedLength(self, *_args, **_kwargs):
        val = apply(windows3c.wxQueryLayoutInfoEvent_SetRequestedLength,(self,) + _args, _kwargs)
        return val
    def GetRequestedLength(self, *_args, **_kwargs):
        val = apply(windows3c.wxQueryLayoutInfoEvent_GetRequestedLength,(self,) + _args, _kwargs)
        return val
    def SetFlags(self, *_args, **_kwargs):
        val = apply(windows3c.wxQueryLayoutInfoEvent_SetFlags,(self,) + _args, _kwargs)
        return val
    def GetFlags(self, *_args, **_kwargs):
        val = apply(windows3c.wxQueryLayoutInfoEvent_GetFlags,(self,) + _args, _kwargs)
        return val
    def SetSize(self, *_args, **_kwargs):
        val = apply(windows3c.wxQueryLayoutInfoEvent_SetSize,(self,) + _args, _kwargs)
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(windows3c.wxQueryLayoutInfoEvent_GetSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def SetOrientation(self, *_args, **_kwargs):
        val = apply(windows3c.wxQueryLayoutInfoEvent_SetOrientation,(self,) + _args, _kwargs)
        return val
    def GetOrientation(self, *_args, **_kwargs):
        val = apply(windows3c.wxQueryLayoutInfoEvent_GetOrientation,(self,) + _args, _kwargs)
        return val
    def SetAlignment(self, *_args, **_kwargs):
        val = apply(windows3c.wxQueryLayoutInfoEvent_SetAlignment,(self,) + _args, _kwargs)
        return val
    def GetAlignment(self, *_args, **_kwargs):
        val = apply(windows3c.wxQueryLayoutInfoEvent_GetAlignment,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxQueryLayoutInfoEvent instance at %s>" % (self.this,)
class wxQueryLayoutInfoEvent(wxQueryLayoutInfoEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows3c.new_wxQueryLayoutInfoEvent,_args,_kwargs)
        self.thisown = 1




class wxCalculateLayoutEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetFlags(self, *_args, **_kwargs):
        val = apply(windows3c.wxCalculateLayoutEvent_SetFlags,(self,) + _args, _kwargs)
        return val
    def GetFlags(self, *_args, **_kwargs):
        val = apply(windows3c.wxCalculateLayoutEvent_GetFlags,(self,) + _args, _kwargs)
        return val
    def SetRect(self, *_args, **_kwargs):
        val = apply(windows3c.wxCalculateLayoutEvent_SetRect,(self,) + _args, _kwargs)
        return val
    def GetRect(self, *_args, **_kwargs):
        val = apply(windows3c.wxCalculateLayoutEvent_GetRect,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def __repr__(self):
        return "<C wxCalculateLayoutEvent instance at %s>" % (self.this,)
class wxCalculateLayoutEvent(wxCalculateLayoutEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows3c.new_wxCalculateLayoutEvent,_args,_kwargs)
        self.thisown = 1




class wxSashLayoutWindowPtr(wxSashWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashLayoutWindow_Create,(self,) + _args, _kwargs)
        return val
    def GetAlignment(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashLayoutWindow_GetAlignment,(self,) + _args, _kwargs)
        return val
    def GetOrientation(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashLayoutWindow_GetOrientation,(self,) + _args, _kwargs)
        return val
    def SetAlignment(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashLayoutWindow_SetAlignment,(self,) + _args, _kwargs)
        return val
    def SetDefaultSize(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashLayoutWindow_SetDefaultSize,(self,) + _args, _kwargs)
        return val
    def SetOrientation(self, *_args, **_kwargs):
        val = apply(windows3c.wxSashLayoutWindow_SetOrientation,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSashLayoutWindow instance at %s>" % (self.this,)
class wxSashLayoutWindow(wxSashLayoutWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows3c.new_wxSashLayoutWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreSashLayoutWindow(*_args,**_kwargs):
    val = wxSashLayoutWindowPtr(apply(windows3c.new_wxPreSashLayoutWindow,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxLayoutAlgorithmPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=windows3c.delete_wxLayoutAlgorithm):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def LayoutMDIFrame(self, *_args, **_kwargs):
        val = apply(windows3c.wxLayoutAlgorithm_LayoutMDIFrame,(self,) + _args, _kwargs)
        return val
    def LayoutFrame(self, *_args, **_kwargs):
        val = apply(windows3c.wxLayoutAlgorithm_LayoutFrame,(self,) + _args, _kwargs)
        return val
    def LayoutWindow(self, *_args, **_kwargs):
        val = apply(windows3c.wxLayoutAlgorithm_LayoutWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxLayoutAlgorithm instance at %s>" % (self.this,)
class wxLayoutAlgorithm(wxLayoutAlgorithmPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows3c.new_wxLayoutAlgorithm,_args,_kwargs)
        self.thisown = 1




class wxPopupWindowPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(windows3c.wxPopupWindow_Create,(self,) + _args, _kwargs)
        return val
    def Position(self, *_args, **_kwargs):
        val = apply(windows3c.wxPopupWindow_Position,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPopupWindow instance at %s>" % (self.this,)
class wxPopupWindow(wxPopupWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows3c.new_wxPopupWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPrePopupWindow(*_args,**_kwargs):
    val = wxPopupWindowPtr(apply(windows3c.new_wxPrePopupWindow,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxPopupTransientWindowPtr(wxPopupWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(windows3c.wxPopupTransientWindow__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def Popup(self, *_args, **_kwargs):
        val = apply(windows3c.wxPopupTransientWindow_Popup,(self,) + _args, _kwargs)
        return val
    def Dismiss(self, *_args, **_kwargs):
        val = apply(windows3c.wxPopupTransientWindow_Dismiss,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPopupTransientWindow instance at %s>" % (self.this,)
class wxPopupTransientWindow(wxPopupTransientWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows3c.new_wxPopupTransientWindow,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPopupTransientWindow)
        self._setOORInfo(self)



def wxPrePopupTransientWindow(*_args,**_kwargs):
    val = wxPopupTransientWindowPtr(apply(windows3c.new_wxPrePopupTransientWindow,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxTipWindowPtr(wxPopupTransientWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetBoundingRect(self, *_args, **_kwargs):
        val = apply(windows3c.wxTipWindow_SetBoundingRect,(self,) + _args, _kwargs)
        return val
    def Close(self, *_args, **_kwargs):
        val = apply(windows3c.wxTipWindow_Close,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTipWindow instance at %s>" % (self.this,)
class wxTipWindow(wxTipWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows3c.new_wxTipWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)






#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------

wxSASH_TOP = windows3c.wxSASH_TOP
wxSASH_RIGHT = windows3c.wxSASH_RIGHT
wxSASH_BOTTOM = windows3c.wxSASH_BOTTOM
wxSASH_LEFT = windows3c.wxSASH_LEFT
wxSASH_NONE = windows3c.wxSASH_NONE
wxEVT_SASH_DRAGGED = windows3c.wxEVT_SASH_DRAGGED
wxSW_3D = windows3c.wxSW_3D
wxSW_3DSASH = windows3c.wxSW_3DSASH
wxSW_3DBORDER = windows3c.wxSW_3DBORDER
wxSW_BORDER = windows3c.wxSW_BORDER
wxSASH_STATUS_OK = windows3c.wxSASH_STATUS_OK
wxSASH_STATUS_OUT_OF_RANGE = windows3c.wxSASH_STATUS_OUT_OF_RANGE
wxLAYOUT_HORIZONTAL = windows3c.wxLAYOUT_HORIZONTAL
wxLAYOUT_VERTICAL = windows3c.wxLAYOUT_VERTICAL
wxLAYOUT_NONE = windows3c.wxLAYOUT_NONE
wxLAYOUT_TOP = windows3c.wxLAYOUT_TOP
wxLAYOUT_LEFT = windows3c.wxLAYOUT_LEFT
wxLAYOUT_RIGHT = windows3c.wxLAYOUT_RIGHT
wxLAYOUT_BOTTOM = windows3c.wxLAYOUT_BOTTOM
wxEVT_QUERY_LAYOUT_INFO = windows3c.wxEVT_QUERY_LAYOUT_INFO
wxEVT_CALCULATE_LAYOUT = windows3c.wxEVT_CALCULATE_LAYOUT



# This file was created automatically by SWIG.
import xrcc

from misc import *

from misc2 import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *

from streams import *

from utils import *

from mdi import *

from frames import *

from stattool import *

from controls import *

from controls2 import *

from windows2 import *

from cmndlgs import *

from windows3 import *

from image import *

from printfw import *

from sizers import *

from filesys import *

def XRCID(str_id):
    return wxXmlResource_GetXRCID(str_id)

def XRCCTRL(window, str_id, *ignoreargs):
    return window.FindWindowById(XRCID(str_id))

XMLID = XRCID
XMLCTRL = XRCCTRL

class wxXmlResourcePtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=xrcc.delete_wxXmlResource):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Load(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_Load,(self,) + _args, _kwargs)
        return val
    def LoadFromString(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadFromString,(self,) + _args, _kwargs)
        return val
    def InitAllHandlers(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_InitAllHandlers,(self,) + _args, _kwargs)
        return val
    def AddHandler(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_AddHandler,(self,) + _args, _kwargs)
        return val
    def InsertHandler(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_InsertHandler,(self,) + _args, _kwargs)
        return val
    def ClearHandlers(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_ClearHandlers,(self,) + _args, _kwargs)
        return val
    def LoadMenu(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadMenu,(self,) + _args, _kwargs)
        return val
    def LoadMenuBar(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadMenuBar,(self,) + _args, _kwargs)
        return val
    def LoadMenuBarOnFrame(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadMenuBarOnFrame,(self,) + _args, _kwargs)
        return val
    def LoadToolBar(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadToolBar,(self,) + _args, _kwargs)
        return val
    def LoadDialog(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadDialog,(self,) + _args, _kwargs)
        if val: val = wxDialogPtr(val) 
        return val
    def LoadOnDialog(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadOnDialog,(self,) + _args, _kwargs)
        return val
    def LoadPanel(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadPanel,(self,) + _args, _kwargs)
        if val: val = wxPanelPtr(val) 
        return val
    def LoadOnPanel(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadOnPanel,(self,) + _args, _kwargs)
        return val
    def LoadFrame(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadFrame,(self,) + _args, _kwargs)
        return val
    def LoadOnFrame(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadOnFrame,(self,) + _args, _kwargs)
        return val
    def LoadObject(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadObject,(self,) + _args, _kwargs)
        return val
    def LoadOnObject(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadOnObject,(self,) + _args, _kwargs)
        return val
    def LoadBitmap(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def LoadIcon(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_LoadIcon,(self,) + _args, _kwargs)
        if val: val = wxIconPtr(val) ; val.thisown = 1
        return val
    def AttachUnknownControl(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_AttachUnknownControl,(self,) + _args, _kwargs)
        return val
    def GetVersion(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_GetVersion,(self,) + _args, _kwargs)
        return val
    def CompareVersion(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_CompareVersion,(self,) + _args, _kwargs)
        return val
    def GetFlags(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_GetFlags,(self,) + _args, _kwargs)
        return val
    def SetFlags(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResource_SetFlags,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxXmlResource instance at %s>" % (self.this,)
class wxXmlResource(wxXmlResourcePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(xrcc.new_wxXmlResource,_args,_kwargs)
        self.thisown = 1
        self.InitAllHandlers()



def wxEmptyXmlResource(*_args,**_kwargs):
    val = wxXmlResourcePtr(apply(xrcc.new_wxEmptyXmlResource,_args,_kwargs))
    val.thisown = 1
    val.InitAllHandlers()
    return val


class wxXmlSubclassFactoryPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlSubclassFactory__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxXmlSubclassFactory instance at %s>" % (self.this,)
class wxXmlSubclassFactory(wxXmlSubclassFactoryPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(xrcc.new_wxXmlSubclassFactory,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxXmlSubclassFactory)




class wxXmlPropertyPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetName(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlProperty_GetName,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlProperty_GetValue,(self,) + _args, _kwargs)
        return val
    def GetNext(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlProperty_GetNext,(self,) + _args, _kwargs)
        if val: val = wxXmlPropertyPtr(val) 
        return val
    def SetName(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlProperty_SetName,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlProperty_SetValue,(self,) + _args, _kwargs)
        return val
    def SetNext(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlProperty_SetNext,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxXmlProperty instance at %s>" % (self.this,)
class wxXmlProperty(wxXmlPropertyPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(xrcc.new_wxXmlProperty,_args,_kwargs)
        self.thisown = 1




class wxXmlNodePtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=xrcc.delete_wxXmlNode):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def AddChild(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_AddChild,(self,) + _args, _kwargs)
        return val
    def InsertChild(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_InsertChild,(self,) + _args, _kwargs)
        return val
    def RemoveChild(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_RemoveChild,(self,) + _args, _kwargs)
        return val
    def AddProperty(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_AddProperty,(self,) + _args, _kwargs)
        return val
    def AddPropertyName(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_AddPropertyName,(self,) + _args, _kwargs)
        return val
    def DeleteProperty(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_DeleteProperty,(self,) + _args, _kwargs)
        return val
    def GetType(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_GetType,(self,) + _args, _kwargs)
        return val
    def GetName(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_GetName,(self,) + _args, _kwargs)
        return val
    def GetContent(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_GetContent,(self,) + _args, _kwargs)
        return val
    def GetParent(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_GetParent,(self,) + _args, _kwargs)
        if val: val = wxXmlNodePtr(val) 
        return val
    def GetNext(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_GetNext,(self,) + _args, _kwargs)
        if val: val = wxXmlNodePtr(val) 
        return val
    def GetChildren(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_GetChildren,(self,) + _args, _kwargs)
        if val: val = wxXmlNodePtr(val) 
        return val
    def GetProperties(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_GetProperties,(self,) + _args, _kwargs)
        if val: val = wxXmlPropertyPtr(val) 
        return val
    def GetPropVal(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_GetPropVal,(self,) + _args, _kwargs)
        return val
    def HasProp(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_HasProp,(self,) + _args, _kwargs)
        return val
    def SetType(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_SetType,(self,) + _args, _kwargs)
        return val
    def SetName(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_SetName,(self,) + _args, _kwargs)
        return val
    def SetContent(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_SetContent,(self,) + _args, _kwargs)
        return val
    def SetParent(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_SetParent,(self,) + _args, _kwargs)
        return val
    def SetNext(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_SetNext,(self,) + _args, _kwargs)
        return val
    def SetChildren(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_SetChildren,(self,) + _args, _kwargs)
        return val
    def SetProperties(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlNode_SetProperties,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxXmlNode instance at %s>" % (self.this,)
class wxXmlNode(wxXmlNodePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(xrcc.new_wxXmlNode,_args,_kwargs)
        self.thisown = 1



def wxXmlNodeEasy(*_args,**_kwargs):
    val = wxXmlNodePtr(apply(xrcc.new_wxXmlNodeEasy,_args,_kwargs))
    val.thisown = 1
    return val


class wxXmlDocumentPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=xrcc.delete_wxXmlDocument):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Load(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_Load,(self,) + _args, _kwargs)
        return val
    def LoadFromStream(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_LoadFromStream,(self,) + _args, _kwargs)
        return val
    def Save(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_Save,(self,) + _args, _kwargs)
        return val
    def SaveToStream(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_SaveToStream,(self,) + _args, _kwargs)
        return val
    def IsOk(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_IsOk,(self,) + _args, _kwargs)
        return val
    def GetRoot(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_GetRoot,(self,) + _args, _kwargs)
        if val: val = wxXmlNodePtr(val) 
        return val
    def GetVersion(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_GetVersion,(self,) + _args, _kwargs)
        return val
    def GetFileEncoding(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_GetFileEncoding,(self,) + _args, _kwargs)
        return val
    def SetRoot(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_SetRoot,(self,) + _args, _kwargs)
        return val
    def SetVersion(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_SetVersion,(self,) + _args, _kwargs)
        return val
    def SetFileEncoding(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_SetFileEncoding,(self,) + _args, _kwargs)
        return val
    def GetEncoding(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_GetEncoding,(self,) + _args, _kwargs)
        return val
    def SetEncoding(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlDocument_SetEncoding,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxXmlDocument instance at %s>" % (self.this,)
class wxXmlDocument(wxXmlDocumentPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(xrcc.new_wxXmlDocument,_args,_kwargs)
        self.thisown = 1



def wxXmlDocumentFromStream(*_args,**_kwargs):
    val = wxXmlDocumentPtr(apply(xrcc.new_wxXmlDocumentFromStream,_args,_kwargs))
    val.thisown = 1
    return val

def wxEmptyXmlDocument(*_args,**_kwargs):
    val = wxXmlDocumentPtr(apply(xrcc.new_wxEmptyXmlDocument,_args,_kwargs))
    val.thisown = 1
    return val


class wxXmlResourceHandlerPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def CreateResource(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_CreateResource,(self,) + _args, _kwargs)
        return val
    def SetParentResource(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_SetParentResource,(self,) + _args, _kwargs)
        return val
    def GetResource(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetResource,(self,) + _args, _kwargs)
        if val: val = wxXmlResourcePtr(val) 
        return val
    def GetNode(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetNode,(self,) + _args, _kwargs)
        if val: val = wxXmlNodePtr(val) 
        return val
    def GetClass(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetClass,(self,) + _args, _kwargs)
        return val
    def GetParent(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetParent,(self,) + _args, _kwargs)
        return val
    def GetInstance(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetInstance,(self,) + _args, _kwargs)
        return val
    def GetParentAsWindow(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetParentAsWindow,(self,) + _args, _kwargs)
        return val
    def GetInstanceAsWindow(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetInstanceAsWindow,(self,) + _args, _kwargs)
        return val
    def IsOfClass(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_IsOfClass,(self,) + _args, _kwargs)
        return val
    def GetNodeContent(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetNodeContent,(self,) + _args, _kwargs)
        return val
    def HasParam(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_HasParam,(self,) + _args, _kwargs)
        return val
    def GetParamNode(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetParamNode,(self,) + _args, _kwargs)
        if val: val = wxXmlNodePtr(val) 
        return val
    def GetParamValue(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetParamValue,(self,) + _args, _kwargs)
        return val
    def AddStyle(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_AddStyle,(self,) + _args, _kwargs)
        return val
    def AddWindowStyles(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_AddWindowStyles,(self,) + _args, _kwargs)
        return val
    def GetStyle(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetStyle,(self,) + _args, _kwargs)
        return val
    def GetText(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetText,(self,) + _args, _kwargs)
        return val
    def GetID(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetID,(self,) + _args, _kwargs)
        return val
    def GetName(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetName,(self,) + _args, _kwargs)
        return val
    def GetBool(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetBool,(self,) + _args, _kwargs)
        return val
    def GetLong(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetLong,(self,) + _args, _kwargs)
        return val
    def GetColour(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetDimension(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetDimension,(self,) + _args, _kwargs)
        return val
    def GetBitmap(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def GetIcon(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetIcon,(self,) + _args, _kwargs)
        if val: val = wxIconPtr(val) ; val.thisown = 1
        return val
    def GetFont(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def SetupWindow(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_SetupWindow,(self,) + _args, _kwargs)
        return val
    def CreateChildren(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_CreateChildren,(self,) + _args, _kwargs)
        return val
    def CreateChildrenPrivately(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_CreateChildrenPrivately,(self,) + _args, _kwargs)
        return val
    def CreateResFromNode(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_CreateResFromNode,(self,) + _args, _kwargs)
        return val
    def GetCurFileSystem(self, *_args, **_kwargs):
        val = apply(xrcc.wxXmlResourceHandler_GetCurFileSystem,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxXmlResourceHandler instance at %s>" % (self.this,)
class wxXmlResourceHandler(wxXmlResourceHandlerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(xrcc.new_wxXmlResourceHandler,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxXmlResourceHandler)






#-------------- FUNCTION WRAPPERS ------------------

wxXmlResource_AddSubclassFactory = xrcc.wxXmlResource_AddSubclassFactory

wxXmlResource_GetXRCID = xrcc.wxXmlResource_GetXRCID

def wxXmlResource_Get(*_args, **_kwargs):
    val = apply(xrcc.wxXmlResource_Get,_args,_kwargs)
    if val: val = wxXmlResourcePtr(val)
    return val

def wxXmlResource_Set(*_args, **_kwargs):
    val = apply(xrcc.wxXmlResource_Set,_args,_kwargs)
    if val: val = wxXmlResourcePtr(val)
    return val



#-------------- VARIABLE WRAPPERS ------------------

wxXRC_USE_LOCALE = xrcc.wxXRC_USE_LOCALE
wxXRC_NO_SUBCLASSING = xrcc.wxXRC_NO_SUBCLASSING
wxXML_ELEMENT_NODE = xrcc.wxXML_ELEMENT_NODE
wxXML_ATTRIBUTE_NODE = xrcc.wxXML_ATTRIBUTE_NODE
wxXML_TEXT_NODE = xrcc.wxXML_TEXT_NODE
wxXML_CDATA_SECTION_NODE = xrcc.wxXML_CDATA_SECTION_NODE
wxXML_ENTITY_REF_NODE = xrcc.wxXML_ENTITY_REF_NODE
wxXML_ENTITY_NODE = xrcc.wxXML_ENTITY_NODE
wxXML_PI_NODE = xrcc.wxXML_PI_NODE
wxXML_COMMENT_NODE = xrcc.wxXML_COMMENT_NODE
wxXML_DOCUMENT_NODE = xrcc.wxXML_DOCUMENT_NODE
wxXML_DOCUMENT_TYPE_NODE = xrcc.wxXML_DOCUMENT_TYPE_NODE
wxXML_DOCUMENT_FRAG_NODE = xrcc.wxXML_DOCUMENT_FRAG_NODE
wxXML_NOTATION_NODE = xrcc.wxXML_NOTATION_NODE
wxXML_HTML_DOCUMENT_NODE = xrcc.wxXML_HTML_DOCUMENT_NODE


#-------------- USER INCLUDE -----------------------


# The global was removed  in favor of static accessor functions.  This is for
# backwards compatibility:
wxTheXmlResource = wxXmlResource_Get()

wx.wxXmlNodePtr = wxXmlNodePtr




#----------------------------------------------------------------------
#  Create a factory for handling the subclass property of the object tag.


def _my_import(name):
    mod = __import__(name)
    components = name.split('.')
    for comp in components[1:]:
        mod = getattr(mod, comp)
    return mod


class wxXmlSubclassFactory_Python(wxXmlSubclassFactory):
    def __init__(self):
        wxXmlSubclassFactory.__init__(self)

    def Create(self, className):
        assert className.find('.') != -1, "Module name must be specified!"
        mname = className[:className.rfind('.')]
        cname = className[className.rfind('.')+1:]
        module = _my_import(mname)
        klass = getattr(module, cname)
        inst = klass()
        return inst


wxXmlResource_AddSubclassFactory(wxXmlSubclassFactory_Python())





"""
sorry no documentation...
Christopher J. Fama
"""



from wxPython.wx import *
from wxPython.html import *

class wxPyClickableHtmlWindow(wxHtmlWindow):
    """
    Class for a wxHtmlWindow which responds to clicks on links by opening a
    browser pointed at that link, and to shift-clicks by copying the link
    to the clipboard.
    """
    def __init__(self,parent,ID,**kw):
        apply(wxHtmlWindow.__init__,(self,parent,ID),kw)

    def OnLinkClicked(self,link):
        self.link = wxTextDataObject(link.GetHref())
        if link.GetEvent().ShiftDown():
            if wxTheClipboard.Open():
                wxTheClipboard.SetData(self.link)
                wxTheClipboard.Close()
            else:
                dlg = wxMessageDialog(self,"Couldn't open clipboard!\n",wxOK)
                wxBell()
                dlg.ShowModal()
                dlg.Destroy()
        else:
            if 0:  # Chris's original code...
                if sys.platform not in ["windows",'nt']           :
                    #TODO: A MORE APPROPRIATE COMMAND LINE FOR Linux
                    #[or rather, non-Windows platforms... as of writing,
                    #this MEANS  Linux, until wxPython for wxMac comes along...]
                    command = "/usr/bin/netscape"
                else:
                    command = "start"
                command = "%s \"%s\"" % (command,
                                         self.link.GetText ())
                os.system (command)

            else:  # My alternative
                import webbrowser
                webbrowser.open(link.GetHref())





# This file was created automatically by SWIG.
import clip_dndc

from misc import *

from gdi import *

from fonts import *
import wx
class wxDataFormatPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=clip_dndc.delete_wxDataFormat):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetType(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataFormat_SetType,(self,) + _args, _kwargs)
        return val
    def GetType(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataFormat_GetType,(self,) + _args, _kwargs)
        return val
    def GetId(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataFormat_GetId,(self,) + _args, _kwargs)
        return val
    def SetId(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataFormat_SetId,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxDataFormat instance at %s>" % (self.this,)
class wxDataFormat(wxDataFormatPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxDataFormat,_args,_kwargs)
        self.thisown = 1




class wxDataObjectPtr :
    Get = clip_dndc.wxDataObject_Get
    Set = clip_dndc.wxDataObject_Set
    Both = clip_dndc.wxDataObject_Both
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=clip_dndc.delete_wxDataObject):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetPreferredFormat(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataObject_GetPreferredFormat,(self,) + _args, _kwargs)
        if val: val = wxDataFormatPtr(val) ; val.thisown = 1
        return val
    def GetFormatCount(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataObject_GetFormatCount,(self,) + _args, _kwargs)
        return val
    def GetAllFormats(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataObject_GetAllFormats,(self,) + _args, _kwargs)
        return val
    def GetDataHere(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataObject_GetDataHere,(self,) + _args, _kwargs)
        return val
    def GetDataSize(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataObject_GetDataSize,(self,) + _args, _kwargs)
        return val
    def SetData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataObject_SetData,(self,) + _args, _kwargs)
        return val
    def IsSupportedFormat(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataObject_IsSupportedFormat,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxDataObject instance at %s>" % (self.this,)
class wxDataObject(wxDataObjectPtr):
    def __init__(self,this):
        self.this = this




class wxDataObjectSimplePtr(wxDataObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetFormat(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataObjectSimple_GetFormat,(self,) + _args, _kwargs)
        if val: val = wxDataFormatPtr(val) 
        return val
    def SetFormat(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataObjectSimple_SetFormat,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxDataObjectSimple instance at %s>" % (self.this,)
class wxDataObjectSimple(wxDataObjectSimplePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxDataObjectSimple,_args,_kwargs)
        self.thisown = 1




class wxPyDataObjectSimplePtr(wxDataObjectSimplePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyDataObjectSimple__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyDataObjectSimple instance at %s>" % (self.this,)
class wxPyDataObjectSimple(wxPyDataObjectSimplePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxPyDataObjectSimple,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyDataObjectSimple)




class wxDataObjectCompositePtr(wxDataObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Add(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDataObjectComposite_Add,(self,) + _args, _kwargs)
        _args[0].thisown = 0
        return val
    def __repr__(self):
        return "<C wxDataObjectComposite instance at %s>" % (self.this,)
class wxDataObjectComposite(wxDataObjectCompositePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxDataObjectComposite,_args,_kwargs)
        self.thisown = 1




class wxTextDataObjectPtr(wxDataObjectSimplePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetTextLength(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxTextDataObject_GetTextLength,(self,) + _args, _kwargs)
        return val
    def GetText(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxTextDataObject_GetText,(self,) + _args, _kwargs)
        return val
    def SetText(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxTextDataObject_SetText,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTextDataObject instance at %s>" % (self.this,)
class wxTextDataObject(wxTextDataObjectPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxTextDataObject,_args,_kwargs)
        self.thisown = 1




class wxPyTextDataObjectPtr(wxTextDataObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyTextDataObject__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyTextDataObject instance at %s>" % (self.this,)
class wxPyTextDataObject(wxPyTextDataObjectPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxPyTextDataObject,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyTextDataObject)




class wxBitmapDataObjectPtr(wxDataObjectSimplePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetBitmap(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxBitmapDataObject_GetBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def SetBitmap(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxBitmapDataObject_SetBitmap,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxBitmapDataObject instance at %s>" % (self.this,)
class wxBitmapDataObject(wxBitmapDataObjectPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxBitmapDataObject,_args,_kwargs)
        self.thisown = 1




class wxPyBitmapDataObjectPtr(wxBitmapDataObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyBitmapDataObject__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyBitmapDataObject instance at %s>" % (self.this,)
class wxPyBitmapDataObject(wxPyBitmapDataObjectPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxPyBitmapDataObject,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyBitmapDataObject)




class wxFileDataObjectPtr(wxDataObjectSimplePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetFilenames(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxFileDataObject_GetFilenames,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFileDataObject instance at %s>" % (self.this,)
class wxFileDataObject(wxFileDataObjectPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxFileDataObject,_args,_kwargs)
        self.thisown = 1




class wxCustomDataObjectPtr(wxDataObjectSimplePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def TakeData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxCustomDataObject_TakeData,(self,) + _args, _kwargs)
        return val
    def SetData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxCustomDataObject_SetData,(self,) + _args, _kwargs)
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxCustomDataObject_GetSize,(self,) + _args, _kwargs)
        return val
    def GetData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxCustomDataObject_GetData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxCustomDataObject instance at %s>" % (self.this,)
class wxCustomDataObject(wxCustomDataObjectPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxCustomDataObject,_args,_kwargs)
        self.thisown = 1




class wxURLDataObjectPtr(wxDataObjectCompositePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetURL(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxURLDataObject_GetURL,(self,) + _args, _kwargs)
        return val
    def SetURL(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxURLDataObject_SetURL,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxURLDataObject instance at %s>" % (self.this,)
class wxURLDataObject(wxURLDataObjectPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxURLDataObject,_args,_kwargs)
        self.thisown = 1




class wxClipboardPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Open(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxClipboard_Open,(self,) + _args, _kwargs)
        return val
    def Close(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxClipboard_Close,(self,) + _args, _kwargs)
        return val
    def IsOpened(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxClipboard_IsOpened,(self,) + _args, _kwargs)
        return val
    def AddData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxClipboard_AddData,(self,) + _args, _kwargs)
        _args[0].thisown = 0
        return val
    def SetData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxClipboard_SetData,(self,) + _args, _kwargs)
        _args[0].thisown = 0
        return val
    def IsSupported(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxClipboard_IsSupported,(self,) + _args, _kwargs)
        return val
    def GetData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxClipboard_GetData,(self,) + _args, _kwargs)
        return val
    def Clear(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxClipboard_Clear,(self,) + _args, _kwargs)
        return val
    def Flush(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxClipboard_Flush,(self,) + _args, _kwargs)
        return val
    def UsePrimarySelection(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxClipboard_UsePrimarySelection,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxClipboard instance at %s>" % (self.this,)
class wxClipboard(wxClipboardPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxClipboard,_args,_kwargs)
        self.thisown = 1




class wxDropSourcePtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDropSource__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __del__(self, delfunc=clip_dndc.delete_wxDropSource):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDropSource_SetData,(self,) + _args, _kwargs)
        return val
    def GetDataObject(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDropSource_GetDataObject,(self,) + _args, _kwargs)
        if val: val = wxDataObjectPtr(val) 
        return val
    def SetCursor(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDropSource_SetCursor,(self,) + _args, _kwargs)
        return val
    def DoDragDrop(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDropSource_DoDragDrop,(self,) + _args, _kwargs)
        return val
    def base_GiveFeedback(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxDropSource_base_GiveFeedback,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxDropSource instance at %s>" % (self.this,)
class wxDropSource(wxDropSourcePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxDropSource,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxDropSource, 0)




class wxDropTargetPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxDropTarget instance at %s>" % (self.this,)
class wxDropTarget(wxDropTargetPtr):
    def __init__(self,this):
        self.this = this




class wxPyDropTargetPtr(wxDropTargetPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyDropTarget__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __del__(self, delfunc=clip_dndc.delete_wxPyDropTarget):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetDataObject(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyDropTarget_GetDataObject,(self,) + _args, _kwargs)
        if val: val = wxDataObjectPtr(val) 
        return val
    def SetDataObject(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyDropTarget_SetDataObject,(self,) + _args, _kwargs)
        if _args:_args[0].thisown = 0
        return val
    def base_OnEnter(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyDropTarget_base_OnEnter,(self,) + _args, _kwargs)
        return val
    def base_OnDragOver(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyDropTarget_base_OnDragOver,(self,) + _args, _kwargs)
        return val
    def base_OnLeave(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyDropTarget_base_OnLeave,(self,) + _args, _kwargs)
        return val
    def base_OnDrop(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyDropTarget_base_OnDrop,(self,) + _args, _kwargs)
        return val
    def GetData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxPyDropTarget_GetData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyDropTarget instance at %s>" % (self.this,)
class wxPyDropTarget(wxPyDropTargetPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxPyDropTarget,_args,_kwargs)
        self.thisown = 1
        if _args:_args[0].thisown = 0
        self._setCallbackInfo(self, wxPyDropTarget)




class wxTextDropTargetPtr(wxPyDropTargetPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxTextDropTarget__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_OnEnter(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxTextDropTarget_base_OnEnter,(self,) + _args, _kwargs)
        return val
    def base_OnDragOver(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxTextDropTarget_base_OnDragOver,(self,) + _args, _kwargs)
        return val
    def base_OnLeave(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxTextDropTarget_base_OnLeave,(self,) + _args, _kwargs)
        return val
    def base_OnDrop(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxTextDropTarget_base_OnDrop,(self,) + _args, _kwargs)
        return val
    def base_OnData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxTextDropTarget_base_OnData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTextDropTarget instance at %s>" % (self.this,)
class wxTextDropTarget(wxTextDropTargetPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxTextDropTarget,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxTextDropTarget)




class wxFileDropTargetPtr(wxPyDropTargetPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxFileDropTarget__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_OnEnter(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxFileDropTarget_base_OnEnter,(self,) + _args, _kwargs)
        return val
    def base_OnDragOver(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxFileDropTarget_base_OnDragOver,(self,) + _args, _kwargs)
        return val
    def base_OnLeave(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxFileDropTarget_base_OnLeave,(self,) + _args, _kwargs)
        return val
    def base_OnDrop(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxFileDropTarget_base_OnDrop,(self,) + _args, _kwargs)
        return val
    def base_OnData(self, *_args, **_kwargs):
        val = apply(clip_dndc.wxFileDropTarget_base_OnData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFileDropTarget instance at %s>" % (self.this,)
class wxFileDropTarget(wxFileDropTargetPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(clip_dndc.new_wxFileDropTarget,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxFileDropTarget)






#-------------- FUNCTION WRAPPERS ------------------

def wxCustomDataFormat(*_args, **_kwargs):
    val = apply(clip_dndc.wxCustomDataFormat,_args,_kwargs)
    if val: val = wxDataFormatPtr(val); val.thisown = 1
    return val

wxIsDragResultOk = clip_dndc.wxIsDragResultOk



#-------------- VARIABLE WRAPPERS ------------------

wxDF_INVALID = clip_dndc.wxDF_INVALID
wxDF_TEXT = clip_dndc.wxDF_TEXT
wxDF_BITMAP = clip_dndc.wxDF_BITMAP
wxDF_METAFILE = clip_dndc.wxDF_METAFILE
wxDF_SYLK = clip_dndc.wxDF_SYLK
wxDF_DIF = clip_dndc.wxDF_DIF
wxDF_TIFF = clip_dndc.wxDF_TIFF
wxDF_OEMTEXT = clip_dndc.wxDF_OEMTEXT
wxDF_DIB = clip_dndc.wxDF_DIB
wxDF_PALETTE = clip_dndc.wxDF_PALETTE
wxDF_PENDATA = clip_dndc.wxDF_PENDATA
wxDF_RIFF = clip_dndc.wxDF_RIFF
wxDF_WAVE = clip_dndc.wxDF_WAVE
wxDF_UNICODETEXT = clip_dndc.wxDF_UNICODETEXT
wxDF_ENHMETAFILE = clip_dndc.wxDF_ENHMETAFILE
wxDF_FILENAME = clip_dndc.wxDF_FILENAME
wxDF_LOCALE = clip_dndc.wxDF_LOCALE
wxDF_PRIVATE = clip_dndc.wxDF_PRIVATE
wxDF_HTML = clip_dndc.wxDF_HTML
wxDF_MAX = clip_dndc.wxDF_MAX
cvar = clip_dndc.cvar
wxFormatInvalid = wxDataFormatPtr(clip_dndc.cvar.wxFormatInvalid)
wxTheClipboard = wxClipboardPtr(clip_dndc.cvar.wxTheClipboard)
wxDrag_CopyOnly = clip_dndc.wxDrag_CopyOnly
wxDrag_AllowMove = clip_dndc.wxDrag_AllowMove
wxDrag_DefaultMove = clip_dndc.wxDrag_DefaultMove
wxDragError = clip_dndc.wxDragError
wxDragNone = clip_dndc.wxDragNone
wxDragCopy = clip_dndc.wxDragCopy
wxDragMove = clip_dndc.wxDragMove
wxDragLink = clip_dndc.wxDragLink
wxDragCancel = clip_dndc.wxDragCancel



#----------------------------------------------------------------------
# Name:        wxPython.lib.imageutils
# Purpose:     A collection of functions for simple image manipulations
#
# Author:      Robb Shecter
#
# Created:     7-Nov-2002
# RCS-ID:      $Id: imageutils.py,v 1.1.2.2 2002/12/20 16:09:11 RD Exp $
# Copyright:   (c) 2002 by
# Licence:     wxWindows license
#----------------------------------------------------------------------

from __future__ import nested_scopes


def grayOut(anImage):
    """
    Convert the given image (in place) to a grayed-out
    version, appropriate for a 'disabled' appearance.
    """
    factor = 0.7        # 0 < f < 1.  Higher is grayer.
    if anImage.HasMask():
        maskColor = (anImage.GetMaskRed(), anImage.GetMaskGreen(), anImage.GetMaskBlue())
    else:
        maskColor = None
    data = map(ord, list(anImage.GetData()))

    for i in range(0, len(data), 3):
        pixel = (data[i], data[i+1], data[i+2])
        pixel = makeGray(pixel, factor, maskColor)
        for x in range(3):
            data[i+x] = pixel[x]
    anImage.SetData(''.join(map(chr, data)))


def makeGray((r,g,b), factor, maskColor):
    """
    Make a pixel grayed-out. If the pixel
    matches the maskColor, it won't be
    changed.
    """
    if (r,g,b) != maskColor:
        return map(lambda x: ((230 - x) * factor) + x, (r,g,b))
    else:
        return (r,g,b)



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Panel.py,v 1.1.2.2 2003/03/20 23:14:27 RD Exp $"
__revision__ = "$Revision: 1.1.2.2 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx
from Window import Window

try:
    True
except NameError:
    True = 1==1
    False = 1==0


class Panel(Window):
    """"""

    def __init__(self, parent, id, pos=wx.DefaultPosition,
                 size=wx.DefaultSize, style=wx.TAB_TRAVERSAL,
                 name=wx.PyPanelNameStr):
        """"""
        pass

    def Create(self, parent, id, pos=wx.DefaultPosition,
               size=wx.DefaultSize, style=wx.TAB_TRAVERSAL,
               name=wx.PyPanelNameStr):
        """"""
        pass

    def InitDialog(self):
        """"""
        pass


class PyPanel(Panel):
    """"""

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass

    def base_AcceptsFocus(self):
        """"""
        pass

    def base_AcceptsFocusFromKeyboard(self):
        """"""
        pass

    def base_AddChild(self):
        """"""
        pass

    def base_DoGetBestSize(self):
        """"""
        pass

    def base_DoGetClientSize(self):
        """"""
        pass

    def base_DoGetPosition(self):
        """"""
        pass

    def base_DoGetSize(self):
        """"""
        pass

    def base_DoGetVirtualSize(self):
        """"""
        pass

    def base_DoMoveWindow(self):
        """"""
        pass

    def base_DoSetClientSize(self):
        """"""
        pass

    def base_DoSetSize(self):
        """"""
        pass

    def base_DoSetVirtualSize(self):
        """"""
        pass

    def base_GetMaxSize(self):
        """"""
        pass

    def base_InitDialog(self):
        """"""
        pass

    def base_RemoveChild(self):
        """"""
        pass

    def base_TransferDataFromWindow(self):
        """"""
        pass

    def base_TransferDataToWindow(self):
        """"""
        pass

    def base_Validate(self):
        """"""
        pass


class ScrolledWindow(Panel):
    """"""

    def __init__(self, parent, id=-1, pos=wx.DefaultPosition,
                 size=wx.DefaultSize, style=wx.HSCROLL|wx.VSCROLL,
                 name=wx.PyPanelNameStr):
        """"""
        pass

    def Create(self, parent, id=-1, pos=wx.DefaultPosition,
               size=wx.DefaultSize, style=wx.HSCROLL|wx.VSCROLL,
               name=wx.PyPanelNameStr):
        """"""
        pass

    def AdjustScrollbars(self):
        """"""
        pass

    def CalcScrolledPosition(self, *args):
        """*args can be a point or (x, y) tuple"""
        pass

    def CalcScrolledPosition1(self, pt):
        """"""
        pass

    def CalcScrolledPosition2(self, x, y):
        """"""
        pass

    def CalcUnscrolledPosition(self, *args):
        """*args can be a point or (x, y) tuple"""
        pass

    def CalcUnscrolledPosition1(self, pt):
        """"""
        pass

    def CalcUnscrolledPosition2(self, x, y):
        """"""
        pass

    def EnableScrolling(self, xScrolling, yScrolling):
        """"""
        pass

    def GetScaleX(self):
        """"""
        pass

    def GetScaleY(self):
        """"""
        pass

    def GetScrollPageSize(self, orient):
        """"""
        pass

    def GetScrollPixelsPerUnit(self):
        """"""
        pass

    def GetTargetWindow(self):
        """"""
        pass

    def GetViewStart(self):
        """"""
        pass

    def IsRetained(self):
        """"""
        pass

    def Layout(self):
        """"""
        pass

    def PrepareDC(self, dc):
        """"""
        pass

    def Scroll(self, x, y):
        """"""
        pass

    def SetScale(self, xs, ys):
        """"""
        pass

    def SetScrollPageSize(self, orient, pageSize):
        """"""
        pass

    def SetScrollRate(self, xstep, ystep):
        """Set the x, y scrolling increments."""
        pass

    def SetScrollbars(self, pixelsPerUnitX, pixelsPerUnitY,
                      noUnitsX, noUnitsY, xPos=0, yPos=0, noRefresh=False):
        """"""
        pass

    def SetTargetWindow(self, window):
        """"""
        pass

    def ViewStart(self):
        """"""
        pass




#----------------------------------------------------------------------
# Name:        wxPython.lib.editor
# Purpose:     A package containing a colourizable text editror
#
# Author:      Robin Dunn
#
# Created:     30-Dec-1999
# RCS-ID:      $Id: __init__.py,v 1.5 2001/12/01 02:22:57 RD Exp $
# Copyright:   (c) 1999 by Total Control Software
# Licence:     wxWindows license
#----------------------------------------------------------------------

# This file makes this directory into a Python package


# import the main classes into the package namespace.
from editor    import wxEditor



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Errors.py,v 1.1.2.1 2003/03/11 19:37:13 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


class PyAssertionError(AssertionError):
    """"""
    pass


class PyDeadObjectError(AttributeError):
    """Instances of wx objects that are OOR capable will have their
    __class__ attribute changed to a _wxPyDeadObject class when the
    C++ object is deleted.  Subsequent attempts to access object
    attributes will raise this error, rather than segfault."""
    pass



"""Decorator utility for documentation and shell scripting.

When you import stc from this module, all of the classes get decorated
with docstrings from our decoration class definitions.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: d_stc.py,v 1.1.2.1 2003/03/11 19:37:11 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]

from wxPython import stc

import stc_

import decorator

decorator.decorate(real=stc, decoration=stc_)



#----------------------------------------------------------------------------
# Name:         ColourSelect.py
# Purpose:      Colour Box Selection Control
#
# Author:       Lorne White, Lorne.White@telusplanet.net
#
# Created:      Feb 25, 2001
# Licence:      wxWindows license
#----------------------------------------------------------------------------

from wxPython.wx import *

# creates a colour wxButton with selectable color
# button click provides a colour selection box
# button colour will change to new colour
# GetColour method to get the selected colour

# Updates:
# call back to function if changes made

# Cliff Wells, logiplexsoftware@earthlink.net:
# - Made ColourSelect into "is a button" rather than "has a button"
# - Added label parameter and logic to adjust the label colour according to the background
#   colour
# - Added id argument
# - Rearranged arguments to more closely follow wx conventions
# - Simplified some of the code

# Cliff Wells, 2002/02/07
# - Added ColourSelect Event

EVT_COMMAND_COLOURSELECT = wxNewId()

class ColourSelectEvent(wxPyCommandEvent):
        def __init__(self, id, value):
                wxPyCommandEvent.__init__(self, id = id)
                self.SetEventType(EVT_COMMAND_COLOURSELECT)
                self.value = value

        def GetValue(self):
                return self.value

def EVT_COLOURSELECT(win, id, func):
    win.Connect(id, -1, EVT_COMMAND_COLOURSELECT, func)

class ColourSelect(wxButton):
    def __init__(self, parent, id, label = "", bcolour=(0, 0, 0),
            pos = wxDefaultPosition, size = wxDefaultSize,
                callback = None):
        wxButton.__init__(self, parent, id, label, pos=pos, size=size)
        self.SetColour(bcolour)
        self.callback = callback
        EVT_BUTTON(parent, self.GetId(), self.OnClick)

    def GetColour(self):
        return self.set_colour

    def GetValue(self):
        return self.set_colour

    def SetColour(self, bcolour):
        self.set_colour_val = wxColor(bcolour[0], bcolour[1], bcolour[2])
        self.SetBackgroundColour(self.set_colour_val)
        avg = reduce(lambda a, b: a + b, bcolour) / 3
        fcolour = avg > 128 and (0, 0, 0) or (255, 255, 255)
        self.SetForegroundColour(apply(wxColour, fcolour))
        self.set_colour = bcolour

    def SetValue(self, bcolour):
        self.SetColour(bcolour)

    def OnChange(self):
        wxPostEvent(self, ColourSelectEvent(self.GetId(), self.GetValue()))
        if self.callback is not None:
            self.callback()

    def OnClick(self, event):
        data = wxColourData()
        data.SetChooseFull(True)
        data.SetColour(self.set_colour_val)
        dlg = wxColourDialog(self.GetParent(), data)
        changed = dlg.ShowModal() == wxID_OK
        if changed:
            data = dlg.GetColourData()
            self.SetColour(data.GetColour().Get())
        dlg.Destroy()

        if changed:
            self.OnChange() # moved after dlg.Destroy, since who knows what the callback will do...

